@@ -94,19 +94,33 @@
 #'         secondPart = "age",
 #'         index = "hfa")
 #'
+#' # Calculate MUAC-for-age (mfa) for the anthro4 dataset
+#'
+#' ## Convert age in anthro4 from months to days
+#' testData <- anthro4
+#' testData$age <- testData$agemons * (365.25 / 12)
+#'
+#' addWGSR(data = testData,
+#'         sex = "sex",
+#'         firstPart = "muac",
+#'         secondPart = "age",
+#'         index = "mfa")
+#'
 #' @export
 #'
+#'
 #
 ################################################################################
 
-addWGSR <- function(data, sex, firstPart, secondPart, thirdPart = NA, index = NA,
-                    standing = NULL, output = paste(index, "z", sep = ""), digits = 2) {
-  ## If 'standing' is not specified then create a column in 'data' holding 3
-  ## (unknown) for all rows
+addWGSR <- function(data, sex, firstPart, secondPart, thirdPart = NA,
+                    index = NA, standing = NULL,
+                    output = paste(index, "z", sep = ""), digits = 2) {
+  ## If 'standing' is not specified then create a column in 'data' holding 3 (unknown) for all rows
   addedStanding <- FALSE
   if(is.null(standing)) {
     ## Random column name for 'standing'
-    standing <- paste(sample(c(letters, LETTERS), size = 16, replace = TRUE), collapse = "")
+    standing <- paste(sample(c(letters, LETTERS), size = 16, replace = TRUE),
+                      collapse = "")
     data[[standing]] <- 3
     addedStanding <- TRUE
   }
@@ -116,12 +130,12 @@ addWGSR <- function(data, sex, firstPart, secondPart, thirdPart = NA, index = NA
   for(i in 1:nrow(data)) {
     z[i] <- ifelse(!is.na(thirdPart),
                    getWGSR(sex = data[[sex]][i], firstPart = data[[firstPart]][i],
-                           secondPart = data[[secondPart]][i], index = index,
-                           standing = data[[standing]][i],
+                           secondPart = data[[secondPart]][i],
+                           index = index, standing = data[[standing]][i],
                            thirdPart = data[[thirdPart]][i]),
                    getWGSR(sex = data[[sex]][i], firstPart = data[[firstPart]][i],
-                           secondPart = data[[secondPart]][i], index = index,
-                           standing = data[[standing]][i]))
+                           secondPart = data[[secondPart]][i],
+                           index = index, standing = data[[standing]][i]))
     setTxtProgressBar(pb, i)
   }
   cat("\n", sep = "")
@@ -199,7 +213,7 @@ addWGSR <- function(data, sex, firstPart, secondPart, thirdPart = NA, index = NA
 #'   \code{3 = Unknown}. Give a quoted variable name as in (e.g.) \code{"measured"}
 #'   or a single value (e.g.\code{"measured = 1"}). If no value (or NULL) is
 #'   specified then height and age rules will be applied.
-#'
+#'zz
 #' @return A numeric value or vector of z-scores for the specified \code{index}.
 #'
 #' @examples
@@ -227,19 +241,26 @@ addWGSR <- function(data, sex, firstPart, secondPart, thirdPart = NA, index = NA
 #'         index = "hfa",
 #'         standing = 3)
 #'
+#' # Calculate MUAC-for-age z-score for a girl
+#' getWGSR(sex = 1,
+#'         firstPart = 20,
+#'         secondPart = 62 * (365.25 / 12),
+#'         index = "mfa")
+#'
 #' @export
 #'
 #
 ################################################################################
 
 getWGSR <- function(sex, firstPart, secondPart,
-                    index = NA, standing, thirdPart = NA) {
+                    index = NA, standing = NA, thirdPart = NA) {
   ## Avoid missing and impossible values in 'standing' by coding NA and other values to '3'
-  if(is.na(standing) | !standing %in% c(1, 2, 3)) {
+  if(is.na(standing) | !(standing %in% c(1, 2, 3))) {
     standing = 3
   }
   ## Unknown index specified - return NA
-  if(!index %in% c("bfa", "hca", "hfa", "lfa", "mfa", "ssa", "tsa", "wfa", "wfh", "wfl")) {
+  if(!(index %in% c("bfa", "hca", "hfa", "lfa", "mfa",
+                    "ssa", "tsa", "wfa", "wfh", "wfl"))) {
     return(NA)
   }
   ## Missing data for 'sex', 'firstPart', or 'secondPart' - return NA
@@ -262,6 +283,10 @@ getWGSR <- function(sex, firstPart, secondPart,
   if(index == "bfa" & !is.numeric(thirdPart)) {
     return(NA)
   }
+  ## 'secondPart' is zero then BMI cannot be calculated
+  if(index == "bfa" & secondPart == 0) {
+    return(NA)
+  }
   ## Round lengths to nearest 0.1 cm
   if(index %in% c("wfh", "wfl")) {
     secondPart <- round(secondPart, 1)
@@ -334,9 +359,9 @@ getWGSR <- function(sex, firstPart, secondPart,
   }
   ## Lookup reference values and calculate z-score
   lkpIndexSex <- wgsrData[wgsrData$index == index & wgsrData$sex == sex, ]
-  L <- approx(lkpIndexSex$given, lkpIndexSex$l, xout = secondPart)$y
-  M <- approx(lkpIndexSex$given, lkpIndexSex$m, xout = secondPart)$y
-  S <- approx(lkpIndexSex$given, lkpIndexSex$s, xout = secondPart)$y
+  L <- approx(lkpIndexSex$given, lkpIndexSex$l, xout = secondPart, ties = "ordered")$y
+  M <- approx(lkpIndexSex$given, lkpIndexSex$m, xout = secondPart, ties = "ordered")$y
+  S <- approx(lkpIndexSex$given, lkpIndexSex$s, xout = secondPart, ties = "ordered")$y
   z <- (((firstPart / M) ^ L) - 1) / (L * S)
   SD3pos <- M * (1 + L * S * (+3))^(1 / L)
   SD2pos <- M * (1 + L * S * (+2))^(1 / L)
