@@ -1,10 +1,12 @@
 ################################################################################
 #
-#' run_zscorer
+#'
+#' Initialise built-in Shiny application
 #'
 #' @return NULL
+#'
 #' @examples
-#' #
+#' if(interactive()) run_zscorer()
 #'
 #' @export
 #
@@ -12,7 +14,8 @@ run_zscorer <- function() {
   appDir <- system.file("zscorer", package = "zscorer")
 
   if (appDir == "") {
-    stop("Could not find Shiny directory. Try re-installing `zscorer`.", call. = FALSE)
+    stop("Could not find Shiny directory. Try re-installing `zscorer`.",
+         call. = FALSE)
   }
 
   shiny::runApp(appDir, display.mode = "normal")
